module.exports = defineTest({
	description: 'splits up multiple vars in a single export declaration'
});
